<?php

/**
 * @file
 */

/**
 * @see taxonomy_term_set_field_form()
 */
function taxonomy_term_set_field_form($form, &$form_state, $edit = array(), $vocabulary = NULL) {

  $module_path = drupal_get_path('module', 'taxonomy_term_list_manager');
  drupal_add_js($module_path . '/js/taxonomy_term_list_manager.js', array('weight' => 100));

  // During initial form build, add the term entity to the form state for use
  // during form building and processing. During a rebuild, use what is in the
  // form state.
  if (!isset($form_state['term'])) {
    $term = is_object($edit) ? $edit : (object) $edit;
    if (!isset($vocabulary) && isset($term->vid)) {
      $vocabulary = taxonomy_vocabulary_load($term->vid);
    }
    $defaults = array(
      'name' => '',
      'description' => '',
      'format' => NULL,
      'vocabulary_machine_name' => isset($vocabulary) ? $vocabulary->machine_name : NULL,
      'tid' => NULL,
      'weight' => 0,
    );
    foreach ($defaults as $key => $value) {
      if (!isset($term->$key)) {
        $term->$key = $value;
      }
    }
    $form_state['term'] = $term;
  }
  else {
    $term = $form_state['term'];
    if (!isset($vocabulary) && isset($term->vid)) {
      $vocabulary = taxonomy_vocabulary_load($term->vid);
    }
  }
  $form['#vocabulary'] = $vocabulary;

  $vocabulary_machine_name = $form['#vocabulary']->machine_name;

  $instances = field_info_instances('taxonomy_term', $vocabulary_machine_name);

  $form['manual_title'] = array(
    '#markup' => "<h2>Select custom fields to categories the display for the view </h2></br>",
  );

  if (!empty($instances)) {
    foreach ($instances as $key => $value) {

      $db_selected_field = $vocabulary_machine_name . '_' . $key . '_cstm_taxonomy';
      $selected_field_name = variable_get($db_selected_field, '');

      $form[$key] = array(
        '#title' => check_plain(t($value['label'])),
        '#type' => 'checkbox',
        '#default_value' => '',
        '#attributes' => !empty($selected_field_name) ? array('checked' => 'checked') : '',
        '#prefix' => '<div class="fullwidth">',
        '#suffix' => '</div>',
      );
    }
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Submit'),
    );
  }
  else {
    $form['msg'] = array(
      '#type' => 'markup',
      '#prefix' => '<b> No Custom fields available in this taxonomy. </b>',
    );
  }
  return $form;
}

/**
 * Submit handler to set term fields form.
 *
 * @see taxonomy_term_set_field_form_submit()
 */
function taxonomy_term_set_field_form_submit($form, &$form_state) {
  $term = $form_state['term'];
  $vocabulary_machine_name = $term->vocabulary_machine_name;
  $fields_input = $form_state['input'];

  foreach ($fields_input as $key => $value) {
    if (0 === strpos($key, 'field_')) {
      if (isset($_POST[$key])) {
        variable_set($vocabulary_machine_name . '_' . $key . '_cstm_taxonomy', $key);
      }
      else {
        variable_del($vocabulary_machine_name . '_' . $key . '_cstm_taxonomy');
      }
    }
  }
  drupal_set_message(t('Settings saved successfully'),'status');
  drupal_goto('admin/structure/taxonomy/' . $vocabulary_machine_name);
}
